pub unsafe trait BundleFromComponents { }Expand description
Creates a Bundle by taking it from internal storage.
Safety
Manual implementations of this trait are unsupported.
That is, there is no safe way to implement this trait, and you must not do so.
If you want a type to implement Bundle, you must use derive@Bundle.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".